import { getToken, getUserInfo } from '@/util';

const { http } = uni.$u
export const fetchContentInfo = (params) => http.get('/cp/contentInfo/list',
  { params });

export const fetchUsrContentInfo = (params) => {
  const usrInfo = getUserInfo();
  const { openId } = usrInfo;
  return http.get(`/cp/usr/content/rel/${openId}`,
    {
      params,
      header: {
        Authorization: `Bearer ${getToken()}`,
      },
    });
};


export const fetchUsrMeetingInfo = (params) => {
  return http.get(`/cp/usrApply/info/meeting`,
    {
      params,
      header: {
        Authorization: `Bearer ${getToken()}`,
      },
    });
};

export const fetchUsrApplyDetail = (applyId) => {
  return http.get(`/cp/usrApply/${applyId}`,
    {
      header: {
        Authorization: `Bearer ${getToken()}`,
      },
    });
};

export const fetchMeetingTips = (ids = [32, 33]) => {
  return http.get(`/cp/contentInfo/ids/${ids.join(',')}`,
    {
      header: {
        Authorization: `Bearer ${getToken()}`,
      },
    });
};

export const fetchUsrThemeMeetingInfo = (params, type) => {
  return http.get(`/cp/usrApply/info/meeting/${type}`,
    {
      params,
      header: {
        Authorization: `Bearer ${getToken()}`,
      },
    });
};

export const fetchContentDetail = (id) => http.get(`/cp/contentInfo/${id}`);

export const fetchMsgList = (params) => http.get('/cp/msg/list',
  { params });

export const fetchViewCfgList = (params) => http.get('/cp/viewcfg/list',
  { params });

export const fetchFileList = (params) => http.get('/cp/fileInfo/list',
  { params });

export const putUsrRegist = (params, type) => {
  const token = getToken();
  if (!token) {
    return Promise.reject('未登录');
  }
  return http.post(`/cp/usr/regist/${type}`, params, {
    header: {
      Authorization: `Bearer ${token}`,
    },
  });
};

export const fetchEnterpriseList = (params = {}) => http.get(
  '/cp/enterprise/list', {
    params: {
      pageNum: 1,
      pageSize: 999,
      ...params,
    },
    header: {
      Authorization: `Bearer ${getToken()}`,
    },
  });

export const fetchEnterpriseTripList = (params = {}) => http.get(
  '/cp/enterpriseTripInfo/list', {
    params: {
      pageNum: 1,
      pageSize: 999,
      ...params,
    },
    header: {
      Authorization: `Bearer ${getToken()}`,
    },
  });

export const fetchUsrInfo = (usrId) => http.get(
  `/cp/usr/${usrId}`, {
    header: {
      Authorization: `Bearer ${getToken()}`,
    },
  });
export const fetchUsrContent = (contentId, openId) => http.get(
  `/cp/usrContentRel/${openId}/${contentId}`);

export const usrLike = (param) => {
  const openId = getUserInfo().openId;
  return http.post(
    `/cp/contentInfo/${openId}/like`, param);
};

export const usrUnLike = (param) => {
  const openId = getUserInfo().openId;
  return http.post(
    `/cp/contentInfo/${openId}/unlike`, param);
};

export const usrCollect = (param) => {
  const openId = getUserInfo().openId;
  return http.post(
    `/cp/contentInfo/${openId}/collect`, param);
};

export const usrUnCollect = (param) => {
  const openId = getUserInfo().openId;
  return http.post(
    `/cp/contentInfo/${openId}/uncollect`, param);
};

export const fetchUsrTrip = () => {
  const openId = getUserInfo().openId;
  return http.get(`/cp/usr/trip/${openId}`, {
    header: {
      Authorization: `Bearer ${getToken()}`,
    },
  });
};
const staticRules = {
  'userInfo.email': {
    pattern: /\w+([-+.]\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*/,
  },
};
export const formCfg = (key) => {
  return http.get(
    `/system/config/configKey/${key}`);
};

export function getDicts(dictType) {
  return http.get(`/system/dict/data/type/${dictType}`);
}

export const getUsrApplyInfo = () => {
  return http.get(`cp/usrApply/regist/list`, {
    header: {
      Authorization: `Bearer ${getToken()}`,
    },
  });
};
